import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * One of (application, instance).
     *
     * Choose application for most scenarios. If you are using the JVM plugin in New Relic, the instance setting allows your condition to trigger for specific app instances.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#condition_scope AlertCondition#condition_scope}
     *
     * @stability stable
     */
    readonly conditionScope?: string;
    /**
     * Whether the condition is enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#enabled AlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The instance IDs associated with this condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#entities AlertCondition#entities}
     *
     * @stability stable
     */
    readonly entities: number[];
    /**
     * A valid Garbage Collection metric e.g. GC/G1 Young Generation. This is required if you are using apm_jvm_metric with gc_cpu_time condition type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#gc_metric AlertCondition#gc_metric}
     *
     * @stability stable
     */
    readonly gcMetric?: string;
    /**
     * The metric field accepts parameters based on the type set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#metric AlertCondition#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The title of the condition. Must be between 1 and 128 characters, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#name AlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the policy where this condition should be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#policy_id AlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#runbook_url AlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
    /**
     * The type of condition. One of: (apm_kt_metric, browser_metric, mobile_metric, servers_metric, apm_app_metric, apm_jvm_metric).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#type AlertCondition#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * A custom metric to be evaluated.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#user_defined_metric AlertCondition#user_defined_metric}
     *
     * @stability stable
     */
    readonly userDefinedMetric?: string;
    /**
     * One of: (average, min, max, total, sample_size).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#user_defined_value_function AlertCondition#user_defined_value_function}
     *
     * @stability stable
     */
    readonly userDefinedValueFunction?: string;
    /**
     * Automatically close instance-based violations, including JVM health metric violations, after the number of hours specified.
     *
     * Must be: 1, 2, 4, 8, 12 or 24.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#violation_close_timer AlertCondition#violation_close_timer}
     *
     * @stability stable
     */
    readonly violationCloseTimer?: number;
    /**
     * term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#term AlertCondition#term}
     *
     * @stability stable
     */
    readonly term: AlertConditionTerm[];
}
/**
 * @stability stable
 */
export interface AlertConditionTerm {
    /**
     * In minutes, must be in the range of 5 to 120, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#duration AlertCondition#duration}
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * One of (above, below, equal). Defaults to equal.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#operator AlertCondition#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * One of (critical, warning). Defaults to critical.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#priority AlertCondition#priority}
     *
     * @stability stable
     */
    readonly priority?: string;
    /**
     * Must be 0 or greater.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#threshold AlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * One of (all, any).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html#time_function AlertCondition#time_function}
     *
     * @stability stable
     */
    readonly timeFunction: string;
}
export declare function alertConditionTermToTerraform(struct?: AlertConditionTerm): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html newrelic_alert_condition}.
 *
 * @stability stable
 */
export declare class AlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/alert_condition.html newrelic_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AlertConditionConfig);
    private _conditionScope?;
    /**
     * @stability stable
     */
    get conditionScope(): string;
    /**
     * @stability stable
     */
    set conditionScope(value: string);
    /**
     * @stability stable
     */
    resetConditionScope(): void;
    /**
     * @stability stable
     */
    get conditionScopeInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _entities?;
    /**
     * @stability stable
     */
    get entities(): number[];
    /**
     * @stability stable
     */
    set entities(value: number[]);
    /**
     * @stability stable
     */
    get entitiesInput(): number[] | undefined;
    private _gcMetric?;
    /**
     * @stability stable
     */
    get gcMetric(): string;
    /**
     * @stability stable
     */
    set gcMetric(value: string);
    /**
     * @stability stable
     */
    resetGcMetric(): void;
    /**
     * @stability stable
     */
    get gcMetricInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _userDefinedMetric?;
    /**
     * @stability stable
     */
    get userDefinedMetric(): string;
    /**
     * @stability stable
     */
    set userDefinedMetric(value: string);
    /**
     * @stability stable
     */
    resetUserDefinedMetric(): void;
    /**
     * @stability stable
     */
    get userDefinedMetricInput(): string | undefined;
    private _userDefinedValueFunction?;
    /**
     * @stability stable
     */
    get userDefinedValueFunction(): string;
    /**
     * @stability stable
     */
    set userDefinedValueFunction(value: string);
    /**
     * @stability stable
     */
    resetUserDefinedValueFunction(): void;
    /**
     * @stability stable
     */
    get userDefinedValueFunctionInput(): string | undefined;
    private _violationCloseTimer?;
    /**
     * @stability stable
     */
    get violationCloseTimer(): number;
    /**
     * @stability stable
     */
    set violationCloseTimer(value: number);
    /**
     * @stability stable
     */
    resetViolationCloseTimer(): void;
    /**
     * @stability stable
     */
    get violationCloseTimerInput(): number | undefined;
    private _term?;
    /**
     * @stability stable
     */
    get term(): AlertConditionTerm[];
    /**
     * @stability stable
     */
    set term(value: AlertConditionTerm[]);
    /**
     * @stability stable
     */
    get termInput(): AlertConditionTerm[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
