import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AlertMutingRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * The account id of the MutingRule..
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#account_id AlertMutingRule#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The description of the MutingRule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#description AlertMutingRule#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Whether the MutingRule is enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#enabled AlertMutingRule#enabled}
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * The name of the MutingRule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#name AlertMutingRule#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * condition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#condition AlertMutingRule#condition}
     *
     * @stability stable
     */
    readonly condition: AlertMutingRuleCondition;
    /**
     * schedule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#schedule AlertMutingRule#schedule}
     *
     * @stability stable
     */
    readonly schedule?: AlertMutingRuleSchedule;
}
/**
 * @stability stable
 */
export interface AlertMutingRuleConditionConditions {
    /**
     * The attribute on a violation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#attribute AlertMutingRule#attribute}
     *
     * @stability stable
     */
    readonly attribute: string;
    /**
     * The operator used to compare the attribute's value with the supplied value(s).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#operator AlertMutingRule#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * The value(s) to compare against the attribute's value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#values AlertMutingRule#values}
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function alertMutingRuleConditionConditionsToTerraform(struct?: AlertMutingRuleConditionConditions): any;
/**
 * @stability stable
 */
export interface AlertMutingRuleCondition {
    /**
     * The operator used to combine all the MutingRuleConditions within the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#operator AlertMutingRule#operator}
     *
     * @stability stable
     */
    readonly operator: string;
    /**
     * conditions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#conditions AlertMutingRule#conditions}
     *
     * @stability stable
     */
    readonly conditions: AlertMutingRuleConditionConditions[];
}
export declare function alertMutingRuleConditionToTerraform(struct?: AlertMutingRuleConditionOutputReference | AlertMutingRuleCondition): any;
/**
 * @stability stable
 */
export declare class AlertMutingRuleConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AlertMutingRuleCondition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AlertMutingRuleCondition | undefined);
    private _operator?;
    /**
     * @stability stable
     */
    get operator(): string;
    /**
     * @stability stable
     */
    set operator(value: string);
    /**
     * @stability stable
     */
    get operatorInput(): string | undefined;
    private _conditions?;
    /**
     * @stability stable
     */
    get conditions(): AlertMutingRuleConditionConditions[];
    /**
     * @stability stable
     */
    set conditions(value: AlertMutingRuleConditionConditions[]);
    /**
     * @stability stable
     */
    get conditionsInput(): AlertMutingRuleConditionConditions[] | undefined;
}
/**
 * @stability stable
 */
export interface AlertMutingRuleSchedule {
    /**
     * The datetime stamp when the MutingRule schedule should stop repeating.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#end_repeat AlertMutingRule#end_repeat}
     *
     * @stability stable
     */
    readonly endRepeat?: string;
    /**
     * The datetime stamp representing when the MutingRule should end.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#end_time AlertMutingRule#end_time}
     *
     * @stability stable
     */
    readonly endTime?: string;
    /**
     * The frequency the MutingRule schedule repeats. One of [DAILY, WEEKLY, MONTHLY].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#repeat AlertMutingRule#repeat}
     *
     * @stability stable
     */
    readonly repeat?: string;
    /**
     * The number of times the MutingRule schedule should repeat.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#repeat_count AlertMutingRule#repeat_count}
     *
     * @stability stable
     */
    readonly repeatCount?: number;
    /**
     * The datetime stamp representing when the MutingRule should start.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#start_time AlertMutingRule#start_time}
     *
     * @stability stable
     */
    readonly startTime?: string;
    /**
     * The time zone that applies to the MutingRule schedule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#time_zone AlertMutingRule#time_zone}
     *
     * @stability stable
     */
    readonly timeZone: string;
    /**
     * The day(s) of the week that a MutingRule should repeat when the repeat field is set to WEEKLY.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html#weekly_repeat_days AlertMutingRule#weekly_repeat_days}
     *
     * @stability stable
     */
    readonly weeklyRepeatDays?: string[];
}
export declare function alertMutingRuleScheduleToTerraform(struct?: AlertMutingRuleScheduleOutputReference | AlertMutingRuleSchedule): any;
/**
 * @stability stable
 */
export declare class AlertMutingRuleScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AlertMutingRuleSchedule | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AlertMutingRuleSchedule | undefined);
    private _endRepeat?;
    /**
     * @stability stable
     */
    get endRepeat(): string;
    /**
     * @stability stable
     */
    set endRepeat(value: string);
    /**
     * @stability stable
     */
    resetEndRepeat(): void;
    /**
     * @stability stable
     */
    get endRepeatInput(): string | undefined;
    private _endTime?;
    /**
     * @stability stable
     */
    get endTime(): string;
    /**
     * @stability stable
     */
    set endTime(value: string);
    /**
     * @stability stable
     */
    resetEndTime(): void;
    /**
     * @stability stable
     */
    get endTimeInput(): string | undefined;
    private _repeat?;
    /**
     * @stability stable
     */
    get repeat(): string;
    /**
     * @stability stable
     */
    set repeat(value: string);
    /**
     * @stability stable
     */
    resetRepeat(): void;
    /**
     * @stability stable
     */
    get repeatInput(): string | undefined;
    private _repeatCount?;
    /**
     * @stability stable
     */
    get repeatCount(): number;
    /**
     * @stability stable
     */
    set repeatCount(value: number);
    /**
     * @stability stable
     */
    resetRepeatCount(): void;
    /**
     * @stability stable
     */
    get repeatCountInput(): number | undefined;
    private _startTime?;
    /**
     * @stability stable
     */
    get startTime(): string;
    /**
     * @stability stable
     */
    set startTime(value: string);
    /**
     * @stability stable
     */
    resetStartTime(): void;
    /**
     * @stability stable
     */
    get startTimeInput(): string | undefined;
    private _timeZone?;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    get timeZoneInput(): string | undefined;
    private _weeklyRepeatDays?;
    /**
     * @stability stable
     */
    get weeklyRepeatDays(): string[];
    /**
     * @stability stable
     */
    set weeklyRepeatDays(value: string[]);
    /**
     * @stability stable
     */
    resetWeeklyRepeatDays(): void;
    /**
     * @stability stable
     */
    get weeklyRepeatDaysInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html newrelic_alert_muting_rule}.
 *
 * @stability stable
 */
export declare class AlertMutingRule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/alert_muting_rule.html newrelic_alert_muting_rule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AlertMutingRuleConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _condition;
    /**
     * @stability stable
     */
    get condition(): AlertMutingRuleConditionOutputReference;
    /**
     * @stability stable
     */
    putCondition(value: AlertMutingRuleCondition): void;
    /**
     * @stability stable
     */
    get conditionInput(): AlertMutingRuleCondition | undefined;
    private _schedule;
    /**
     * @stability stable
     */
    get schedule(): AlertMutingRuleScheduleOutputReference;
    /**
     * @stability stable
     */
    putSchedule(value: AlertMutingRuleSchedule): void;
    /**
     * @stability stable
     */
    resetSchedule(): void;
    /**
     * @stability stable
     */
    get scheduleInput(): AlertMutingRuleSchedule | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
