import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AlertPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID to operate on.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html#account_id AlertPolicy#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * An array of channel IDs (integers) to assign to the policy.
     *
     * Adding or removing channel IDs from this array will result in a new alert policy resource being created and the old one being destroyed. Also note that channel IDs cannot be imported via terraform import.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html#channel_ids AlertPolicy#channel_ids}
     *
     * @stability stable
     */
    readonly channelIds?: number[];
    /**
     * The rollup strategy for the policy. Options include: PER_POLICY, PER_CONDITION, or PER_CONDITION_AND_TARGET. The default is PER_POLICY.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html#incident_preference AlertPolicy#incident_preference}
     *
     * @stability stable
     */
    readonly incidentPreference?: string;
    /**
     * The name of the policy.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html#name AlertPolicy#name}
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html newrelic_alert_policy}.
 *
 * @stability stable
 */
export declare class AlertPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/alert_policy.html newrelic_alert_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AlertPolicyConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _channelIds?;
    /**
     * @stability stable
     */
    get channelIds(): number[];
    /**
     * @stability stable
     */
    set channelIds(value: number[]);
    /**
     * @stability stable
     */
    resetChannelIds(): void;
    /**
     * @stability stable
     */
    get channelIdsInput(): number[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _incidentPreference?;
    /**
     * @stability stable
     */
    get incidentPreference(): string;
    /**
     * @stability stable
     */
    set incidentPreference(value: string);
    /**
     * @stability stable
     */
    resetIncidentPreference(): void;
    /**
     * @stability stable
     */
    get incidentPreferenceInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
