import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DashboardConfig extends cdktf.TerraformMetaArguments {
    /**
     * Determines who can edit the dashboard in an account.
     *
     * Valid values are all, editable_by_all, editable_by_owner, or read_only. Defaults to editable_by_all.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#editable Dashboard#editable}
     *
     * @stability stable
     */
    readonly editable?: string;
    /**
     * New Relic One supports a 3 column grid or a 12 column grid.
     *
     * New Relic Insights supports a 3 column grid.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#grid_column_count Dashboard#grid_column_count}
     *
     * @stability stable
     */
    readonly gridColumnCount?: number;
    /**
     * The icon for the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#icon Dashboard#icon}
     *
     * @stability stable
     */
    readonly icon?: string;
    /**
     * The title of the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Determines who can see the dashboard in an account. Valid values are all or owner. Defaults to all.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#visibility Dashboard#visibility}
     *
     * @stability stable
     */
    readonly visibility?: string;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#filter Dashboard#filter}
     *
     * @stability stable
     */
    readonly filter?: DashboardFilter;
    /**
     * widget block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#widget Dashboard#widget}
     *
     * @stability stable
     */
    readonly widget?: DashboardWidget[];
}
/**
 * @stability stable
 */
export interface DashboardFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#attributes Dashboard#attributes}.
     *
     * @stability stable
     */
    readonly attributes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#event_types Dashboard#event_types}.
     *
     * @stability stable
     */
    readonly eventTypes: string[];
}
export declare function dashboardFilterToTerraform(struct?: DashboardFilterOutputReference | DashboardFilter): any;
/**
 * @stability stable
 */
export declare class DashboardFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardFilter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardFilter | undefined);
    private _attributes?;
    /**
     * @stability stable
     */
    get attributes(): string[];
    /**
     * @stability stable
     */
    set attributes(value: string[]);
    /**
     * @stability stable
     */
    resetAttributes(): void;
    /**
     * @stability stable
     */
    get attributesInput(): string[] | undefined;
    private _eventTypes?;
    /**
     * @stability stable
     */
    get eventTypes(): string[];
    /**
     * @stability stable
     */
    set eventTypes(value: string[]);
    /**
     * @stability stable
     */
    get eventTypesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetCompareWithPresentation {
    /**
     * The color for the rendered data.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#color Dashboard#color}
     *
     * @stability stable
     */
    readonly color: string;
    /**
     * The name for the rendered data.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function dashboardWidgetCompareWithPresentationToTerraform(struct?: DashboardWidgetCompareWithPresentationOutputReference | DashboardWidgetCompareWithPresentation): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetCompareWithPresentationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetCompareWithPresentation | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetCompareWithPresentation | undefined);
    private _color?;
    /**
     * @stability stable
     */
    get color(): string;
    /**
     * @stability stable
     */
    set color(value: string);
    /**
     * @stability stable
     */
    get colorInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetCompareWith {
    /**
     * The offset duration for the COMPARE WITH clause.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#offset_duration Dashboard#offset_duration}
     *
     * @stability stable
     */
    readonly offsetDuration: string;
    /**
     * presentation block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#presentation Dashboard#presentation}
     *
     * @stability stable
     */
    readonly presentation: DashboardWidgetCompareWithPresentation;
}
export declare function dashboardWidgetCompareWithToTerraform(struct?: DashboardWidgetCompareWith): any;
/**
 * @stability stable
 */
export interface DashboardWidgetMetric {
    /**
     * The metric name to display.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metric scope.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#scope Dashboard#scope}
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * The metric units.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#units Dashboard#units}
     *
     * @stability stable
     */
    readonly units?: string;
    /**
     * The metric values to display.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#values Dashboard#values}
     *
     * @stability stable
     */
    readonly values?: string[];
}
export declare function dashboardWidgetMetricToTerraform(struct?: DashboardWidgetMetric): any;
/**
 * @stability stable
 */
export interface DashboardWidget {
    /**
     * The target account ID to fetch data from, if not the current account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#account_id Dashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * Column position of widget from top left, starting at 1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#column Dashboard#column}
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * The ID of a dashboard to link to from the widget's facets.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#drilldown_dashboard_id Dashboard#drilldown_dashboard_id}
     *
     * @stability stable
     */
    readonly drilldownDashboardId?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#duration Dashboard#duration}.
     *
     * @stability stable
     */
    readonly duration?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#end_time Dashboard#end_time}.
     *
     * @stability stable
     */
    readonly endTime?: number;
    /**
     * A collection of entity ids to display data for. These are typically application IDs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#entity_ids Dashboard#entity_ids}
     *
     * @stability stable
     */
    readonly entityIds?: number[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#facet Dashboard#facet}.
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Height of the widget. Valid values are 1 to 3 inclusive. Defaults to 1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#height Dashboard#height}
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * The limit of distinct data series to display.  Requires `order_by` to be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Description of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#notes Dashboard#notes}
     *
     * @stability stable
     */
    readonly notes?: string;
    /**
     * Valid NRQL query string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#nrql Dashboard#nrql}
     *
     * @stability stable
     */
    readonly nrql?: string;
    /**
     * Set the order of result series.  Required when using `limit`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#order_by Dashboard#order_by}
     *
     * @stability stable
     */
    readonly orderBy?: string;
    /**
     * Row position of widget from top left, starting at 1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#row Dashboard#row}
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * The markdown source to be rendered in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#source Dashboard#source}
     *
     * @stability stable
     */
    readonly source?: string;
    /**
     * Threshold above which the displayed value will be styled with a red color.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#threshold_red Dashboard#threshold_red}
     *
     * @stability stable
     */
    readonly thresholdRed?: number;
    /**
     * Threshold above which the displayed value will be styled with a yellow color.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#threshold_yellow Dashboard#threshold_yellow}
     *
     * @stability stable
     */
    readonly thresholdYellow?: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * How the widget visualizes data.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#visualization Dashboard#visualization}
     *
     * @stability stable
     */
    readonly visualization: string;
    /**
     * Width of the widget. Valid values are 1 to 3 inclusive. Defaults to 1.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#width Dashboard#width}
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * compare_with block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#compare_with Dashboard#compare_with}
     *
     * @stability stable
     */
    readonly compareWith?: DashboardWidgetCompareWith[];
    /**
     * metric block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: DashboardWidgetMetric[];
}
export declare function dashboardWidgetToTerraform(struct?: DashboardWidget): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html newrelic_dashboard}.
 *
 * @stability stable
 */
export declare class Dashboard extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/dashboard.html newrelic_dashboard} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DashboardConfig);
    /**
     * @stability stable
     */
    get dashboardUrl(): string;
    private _editable?;
    /**
     * @stability stable
     */
    get editable(): string;
    /**
     * @stability stable
     */
    set editable(value: string);
    /**
     * @stability stable
     */
    resetEditable(): void;
    /**
     * @stability stable
     */
    get editableInput(): string | undefined;
    private _gridColumnCount?;
    /**
     * @stability stable
     */
    get gridColumnCount(): number;
    /**
     * @stability stable
     */
    set gridColumnCount(value: number);
    /**
     * @stability stable
     */
    resetGridColumnCount(): void;
    /**
     * @stability stable
     */
    get gridColumnCountInput(): number | undefined;
    private _icon?;
    /**
     * @stability stable
     */
    get icon(): string;
    /**
     * @stability stable
     */
    set icon(value: string);
    /**
     * @stability stable
     */
    resetIcon(): void;
    /**
     * @stability stable
     */
    get iconInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _visibility?;
    /**
     * @stability stable
     */
    get visibility(): string;
    /**
     * @stability stable
     */
    set visibility(value: string);
    /**
     * @stability stable
     */
    resetVisibility(): void;
    /**
     * @stability stable
     */
    get visibilityInput(): string | undefined;
    private _filter;
    /**
     * @stability stable
     */
    get filter(): DashboardFilterOutputReference;
    /**
     * @stability stable
     */
    putFilter(value: DashboardFilter): void;
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): DashboardFilter | undefined;
    private _widget?;
    /**
     * @stability stable
     */
    get widget(): DashboardWidget[];
    /**
     * @stability stable
     */
    set widget(value: DashboardWidget[]);
    /**
     * @stability stable
     */
    resetWidget(): void;
    /**
     * @stability stable
     */
    get widgetInput(): DashboardWidget[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
