import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataNewrelicEntityConfig extends cdktf.TerraformMetaArguments {
    /**
     * The entity's domain.
     *
     * Valid values are APM, BROWSER, INFRA, MOBILE, SYNTH, and VIZ. If not specified, all domains are searched.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#domain DataNewrelicEntity#domain}
     *
     * @stability stable
     */
    readonly domain?: string;
    /**
     * Ignore case when searching the entity name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#ignore_case DataNewrelicEntity#ignore_case}
     *
     * @stability stable
     */
    readonly ignoreCase?: boolean | cdktf.IResolvable;
    /**
     * The name of the entity in New Relic One.
     *
     * The first entity matching this name for the given search parameters will be returned.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#name DataNewrelicEntity#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The entity's type. Valid values are APPLICATION, DASHBOARD, HOST, MONITOR, and WORKLOAD.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#type DataNewrelicEntity#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * tag block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#tag DataNewrelicEntity#tag}
     *
     * @stability stable
     */
    readonly tag?: DataNewrelicEntityTag;
}
/**
 * @stability stable
 */
export interface DataNewrelicEntityTag {
    /**
     * The tag key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#key DataNewrelicEntity#key}
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * The tag value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html#value DataNewrelicEntity#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function dataNewrelicEntityTagToTerraform(struct?: DataNewrelicEntityTagOutputReference | DataNewrelicEntityTag): any;
/**
 * @stability stable
 */
export declare class DataNewrelicEntityTagOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataNewrelicEntityTag | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataNewrelicEntityTag | undefined);
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html newrelic_entity}.
 *
 * @stability stable
 */
export declare class DataNewrelicEntity extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/d/entity.html newrelic_entity} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataNewrelicEntityConfig);
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    get applicationId(): number;
    private _domain?;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    set domain(value: string);
    /**
     * @stability stable
     */
    resetDomain(): void;
    /**
     * @stability stable
     */
    get domainInput(): string | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ignoreCase?;
    /**
     * @stability stable
     */
    get ignoreCase(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ignoreCase(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIgnoreCase(): void;
    /**
     * @stability stable
     */
    get ignoreCaseInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get servingApmApplicationId(): number;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _tag;
    /**
     * @stability stable
     */
    get tag(): DataNewrelicEntityTagOutputReference;
    /**
     * @stability stable
     */
    putTag(value: DataNewrelicEntityTag): void;
    /**
     * @stability stable
     */
    resetTag(): void;
    /**
     * @stability stable
     */
    get tagInput(): DataNewrelicEntityTag | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
