import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EntityTagsConfig extends cdktf.TerraformMetaArguments {
    /**
     * The guid of the entity to tag.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#guid EntityTags#guid}
     *
     * @stability stable
     */
    readonly guid: string;
    /**
     * tag block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#tag EntityTags#tag}
     *
     * @stability stable
     */
    readonly tag: EntityTagsTag[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#timeouts EntityTags#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EntityTagsTimeouts;
}
/**
 * @stability stable
 */
export interface EntityTagsTag {
    /**
     * The tag key.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#key EntityTags#key}
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * The tag values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#values EntityTags#values}
     *
     * @stability stable
     */
    readonly values: string[];
}
export declare function entityTagsTagToTerraform(struct?: EntityTagsTag): any;
/**
 * @stability stable
 */
export interface EntityTagsTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html#create EntityTags#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function entityTagsTimeoutsToTerraform(struct?: EntityTagsTimeoutsOutputReference | EntityTagsTimeouts): any;
/**
 * @stability stable
 */
export declare class EntityTagsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EntityTagsTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EntityTagsTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html newrelic_entity_tags}.
 *
 * @stability stable
 */
export declare class EntityTags extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/entity_tags.html newrelic_entity_tags} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EntityTagsConfig);
    private _guid?;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    set guid(value: string);
    /**
     * @stability stable
     */
    get guidInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _tag?;
    /**
     * @stability stable
     */
    get tag(): EntityTagsTag[];
    /**
     * @stability stable
     */
    set tag(value: EntityTagsTag[]);
    /**
     * @stability stable
     */
    get tagInput(): EntityTagsTag[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): EntityTagsTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: EntityTagsTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EntityTagsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
