import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EventsToMetricsRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Account with the event and where the metrics will be put.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html#account_id EventsToMetricsRule#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * Provides additional information about the rule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html#description EventsToMetricsRule#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * True means this rule is enabled. False means the rule is currently not creating metrics.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html#enabled EventsToMetricsRule#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The name of the rule. This must be unique within an account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html#name EventsToMetricsRule#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Explains how to create metrics from events.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html#nrql EventsToMetricsRule#nrql}
     *
     * @stability stable
     */
    readonly nrql: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html newrelic_events_to_metrics_rule}.
 *
 * @stability stable
 */
export declare class EventsToMetricsRule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/events_to_metrics_rule.html newrelic_events_to_metrics_rule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EventsToMetricsRuleConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _nrql?;
    /**
     * @stability stable
     */
    get nrql(): string;
    /**
     * @stability stable
     */
    set nrql(value: string);
    /**
     * @stability stable
     */
    get nrqlInput(): string | undefined;
    /**
     * @stability stable
     */
    get ruleId(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
