import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface InfraAlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * The operator used to evaluate the threshold value.
     *
     * Valid values are above, below, and equal. Supported by the infra_metric and infra_process_running condition types.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#comparison InfraAlertCondition#comparison}
     *
     * @stability stable
     */
    readonly comparison?: string;
    /**
     * The description of the Infrastructure alert condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#description InfraAlertCondition#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Whether the condition is turned on or off. Valid values are true and false. Defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#enabled InfraAlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The metric event; for example, SystemSample or StorageSample. Supported by the infra_metric condition type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#event InfraAlertCondition#event}
     *
     * @stability stable
     */
    readonly event?: string;
    /**
     * For alerts on integrations, use this instead of event. Supported by the infra_metric condition type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#integration_provider InfraAlertCondition#integration_provider}
     *
     * @stability stable
     */
    readonly integrationProvider?: string;
    /**
     * The Infrastructure alert condition's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#name InfraAlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the alert policy where this condition should be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#policy_id InfraAlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Any filters applied to processes; for example: commandName = 'java'. Supported by the infra_process_running condition type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#process_where InfraAlertCondition#process_where}
     *
     * @stability stable
     */
    readonly processWhere?: string;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#runbook_url InfraAlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
    /**
     * The attribute name to identify the metric being targeted;
     *
     * for example, cpuPercent, diskFreePercent, or memoryResidentSizeBytes. The underlying API will automatically populate this value for Infrastructure integrations (for example diskFreePercent), so make sure to explicitly include this value to avoid diff issues. Supported by the infra_metric condition type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#select InfraAlertCondition#select}
     *
     * @stability stable
     */
    readonly select?: string;
    /**
     * The type of Infrastructure alert condition. Valid values are infra_process_running, infra_metric, and infra_host_not_reporting.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#type InfraAlertCondition#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Determines how much time, in hours, will pass before a violation is automatically closed.
     *
     * Valid values are 1, 2, 4, 8, 12, 24, 48, or 72
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#violation_close_timer InfraAlertCondition#violation_close_timer}
     *
     * @stability stable
     */
    readonly violationCloseTimer?: number;
    /**
     * If applicable, this identifies any Infrastructure host filters used; for example: hostname LIKE '%cassandra%'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#where InfraAlertCondition#where}
     *
     * @stability stable
     */
    readonly where?: string;
    /**
     * critical block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#critical InfraAlertCondition#critical}
     *
     * @stability stable
     */
    readonly critical?: InfraAlertConditionCritical;
    /**
     * warning block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#warning InfraAlertCondition#warning}
     *
     * @stability stable
     */
    readonly warning?: InfraAlertConditionWarning;
}
/**
 * @stability stable
 */
export interface InfraAlertConditionCritical {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#duration InfraAlertCondition#duration}.
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#time_function InfraAlertCondition#time_function}.
     *
     * @stability stable
     */
    readonly timeFunction?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#value InfraAlertCondition#value}.
     *
     * @stability stable
     */
    readonly value?: number;
}
export declare function infraAlertConditionCriticalToTerraform(struct?: InfraAlertConditionCriticalOutputReference | InfraAlertConditionCritical): any;
/**
 * @stability stable
 */
export declare class InfraAlertConditionCriticalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): InfraAlertConditionCritical | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: InfraAlertConditionCritical | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _timeFunction?;
    /**
     * @stability stable
     */
    get timeFunction(): string;
    /**
     * @stability stable
     */
    set timeFunction(value: string);
    /**
     * @stability stable
     */
    resetTimeFunction(): void;
    /**
     * @stability stable
     */
    get timeFunctionInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    set value(value: number);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface InfraAlertConditionWarning {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#duration InfraAlertCondition#duration}.
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#time_function InfraAlertCondition#time_function}.
     *
     * @stability stable
     */
    readonly timeFunction?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html#value InfraAlertCondition#value}.
     *
     * @stability stable
     */
    readonly value?: number;
}
export declare function infraAlertConditionWarningToTerraform(struct?: InfraAlertConditionWarningOutputReference | InfraAlertConditionWarning): any;
/**
 * @stability stable
 */
export declare class InfraAlertConditionWarningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): InfraAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: InfraAlertConditionWarning | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _timeFunction?;
    /**
     * @stability stable
     */
    get timeFunction(): string;
    /**
     * @stability stable
     */
    set timeFunction(value: string);
    /**
     * @stability stable
     */
    resetTimeFunction(): void;
    /**
     * @stability stable
     */
    get timeFunctionInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    set value(value: number);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html newrelic_infra_alert_condition}.
 *
 * @stability stable
 */
export declare class InfraAlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/infra_alert_condition.html newrelic_infra_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: InfraAlertConditionConfig);
    private _comparison?;
    /**
     * @stability stable
     */
    get comparison(): string;
    /**
     * @stability stable
     */
    set comparison(value: string);
    /**
     * @stability stable
     */
    resetComparison(): void;
    /**
     * @stability stable
     */
    get comparisonInput(): string | undefined;
    /**
     * @stability stable
     */
    get createdAt(): number;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _event?;
    /**
     * @stability stable
     */
    get event(): string;
    /**
     * @stability stable
     */
    set event(value: string);
    /**
     * @stability stable
     */
    resetEvent(): void;
    /**
     * @stability stable
     */
    get eventInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _integrationProvider?;
    /**
     * @stability stable
     */
    get integrationProvider(): string;
    /**
     * @stability stable
     */
    set integrationProvider(value: string);
    /**
     * @stability stable
     */
    resetIntegrationProvider(): void;
    /**
     * @stability stable
     */
    get integrationProviderInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _processWhere?;
    /**
     * @stability stable
     */
    get processWhere(): string;
    /**
     * @stability stable
     */
    set processWhere(value: string);
    /**
     * @stability stable
     */
    resetProcessWhere(): void;
    /**
     * @stability stable
     */
    get processWhereInput(): string | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    private _select?;
    /**
     * @stability stable
     */
    get select(): string;
    /**
     * @stability stable
     */
    set select(value: string);
    /**
     * @stability stable
     */
    resetSelect(): void;
    /**
     * @stability stable
     */
    get selectInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    /**
     * @stability stable
     */
    get updatedAt(): number;
    private _violationCloseTimer?;
    /**
     * @stability stable
     */
    get violationCloseTimer(): number;
    /**
     * @stability stable
     */
    set violationCloseTimer(value: number);
    /**
     * @stability stable
     */
    resetViolationCloseTimer(): void;
    /**
     * @stability stable
     */
    get violationCloseTimerInput(): number | undefined;
    private _where?;
    /**
     * @stability stable
     */
    get where(): string;
    /**
     * @stability stable
     */
    set where(value: string);
    /**
     * @stability stable
     */
    resetWhere(): void;
    /**
     * @stability stable
     */
    get whereInput(): string | undefined;
    private _critical;
    /**
     * @stability stable
     */
    get critical(): InfraAlertConditionCriticalOutputReference;
    /**
     * @stability stable
     */
    putCritical(value: InfraAlertConditionCritical): void;
    /**
     * @stability stable
     */
    resetCritical(): void;
    /**
     * @stability stable
     */
    get criticalInput(): InfraAlertConditionCritical | undefined;
    private _warning;
    /**
     * @stability stable
     */
    get warning(): InfraAlertConditionWarningOutputReference;
    /**
     * @stability stable
     */
    putWarning(value: InfraAlertConditionWarning): void;
    /**
     * @stability stable
     */
    resetWarning(): void;
    /**
     * @stability stable
     */
    get warningInput(): InfraAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
