import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface InsightsEventConfig extends cdktf.TerraformMetaArguments {
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#event InsightsEvent#event}
     *
     * @stability stable
     */
    readonly event: InsightsEventEvent[];
}
/**
 * @stability stable
 */
export interface InsightsEventEventAttribute {
    /**
     * The name of the attribute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#key InsightsEvent#key}
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Specify the type for the attribute value.
     *
     * This is useful when passing integer or float values to Insights. Allowed values are string, int, or float. Defaults to string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#type InsightsEvent#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * The value of the attribute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#value InsightsEvent#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function insightsEventEventAttributeToTerraform(struct?: InsightsEventEventAttribute): any;
/**
 * @stability stable
 */
export interface InsightsEventEvent {
    /**
     * Must be a Unix epoch timestamp. You can define timestamps either in seconds or in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#timestamp InsightsEvent#timestamp}
     *
     * @stability stable
     */
    readonly timestamp?: number;
    /**
     * The event's name. Can be a combination of alphanumeric characters, underscores, and colons.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#type InsightsEvent#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * attribute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html#attribute InsightsEvent#attribute}
     *
     * @stability stable
     */
    readonly attribute: InsightsEventEventAttribute[];
}
export declare function insightsEventEventToTerraform(struct?: InsightsEventEvent): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html newrelic_insights_event}.
 *
 * @stability stable
 */
export declare class InsightsEvent extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/insights_event.html newrelic_insights_event} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: InsightsEventConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _event?;
    /**
     * @stability stable
     */
    get event(): InsightsEventEvent[];
    /**
     * @stability stable
     */
    set event(value: InsightsEventEvent[]);
    /**
     * @stability stable
     */
    get eventInput(): InsightsEventEvent[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
