import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NewrelicProviderConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#account_id NewrelicProvider#account_id}.
     *
     * @stability stable
     */
    readonly accountId: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#admin_api_key NewrelicProvider#admin_api_key}.
     *
     * @stability stable
     */
    readonly adminApiKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#api_key NewrelicProvider#api_key}.
     *
     * @stability stable
     */
    readonly apiKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#api_url NewrelicProvider#api_url}.
     *
     * @stability stable
     */
    readonly apiUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#cacert_file NewrelicProvider#cacert_file}.
     *
     * @stability stable
     */
    readonly cacertFile?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#infrastructure_api_url NewrelicProvider#infrastructure_api_url}.
     *
     * @stability stable
     */
    readonly infrastructureApiUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#insecure_skip_verify NewrelicProvider#insecure_skip_verify}.
     *
     * @stability stable
     */
    readonly insecureSkipVerify?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#insights_insert_key NewrelicProvider#insights_insert_key}.
     *
     * @stability stable
     */
    readonly insightsInsertKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#insights_insert_url NewrelicProvider#insights_insert_url}.
     *
     * @stability stable
     */
    readonly insightsInsertUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#insights_query_url NewrelicProvider#insights_query_url}.
     *
     * @stability stable
     */
    readonly insightsQueryUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#nerdgraph_api_url NewrelicProvider#nerdgraph_api_url}.
     *
     * @stability stable
     */
    readonly nerdgraphApiUrl?: string;
    /**
     * The data center for which your New Relic account is configured. Only one region per provider block is permitted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#region NewrelicProvider#region}
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#synthetics_api_url NewrelicProvider#synthetics_api_url}.
     *
     * @stability stable
     */
    readonly syntheticsApiUrl?: string;
    /**
     * Alias name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic#alias NewrelicProvider#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic newrelic}.
 *
 * @stability stable
 */
export declare class NewrelicProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic newrelic} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NewrelicProviderConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number | undefined;
    /**
     * @stability stable
     */
    set accountId(value: number | undefined);
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _adminApiKey?;
    /**
     * @stability stable
     */
    get adminApiKey(): string | undefined;
    /**
     * @stability stable
     */
    set adminApiKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetAdminApiKey(): void;
    /**
     * @stability stable
     */
    get adminApiKeyInput(): string | undefined;
    private _apiKey?;
    /**
     * @stability stable
     */
    get apiKey(): string | undefined;
    /**
     * @stability stable
     */
    set apiKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetApiKey(): void;
    /**
     * @stability stable
     */
    get apiKeyInput(): string | undefined;
    private _apiUrl?;
    /**
     * @stability stable
     */
    get apiUrl(): string | undefined;
    /**
     * @stability stable
     */
    set apiUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetApiUrl(): void;
    /**
     * @stability stable
     */
    get apiUrlInput(): string | undefined;
    private _cacertFile?;
    /**
     * @stability stable
     */
    get cacertFile(): string | undefined;
    /**
     * @stability stable
     */
    set cacertFile(value: string | undefined);
    /**
     * @stability stable
     */
    resetCacertFile(): void;
    /**
     * @stability stable
     */
    get cacertFileInput(): string | undefined;
    private _infrastructureApiUrl?;
    /**
     * @stability stable
     */
    get infrastructureApiUrl(): string | undefined;
    /**
     * @stability stable
     */
    set infrastructureApiUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetInfrastructureApiUrl(): void;
    /**
     * @stability stable
     */
    get infrastructureApiUrlInput(): string | undefined;
    private _insecureSkipVerify?;
    /**
     * @stability stable
     */
    get insecureSkipVerify(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set insecureSkipVerify(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetInsecureSkipVerify(): void;
    /**
     * @stability stable
     */
    get insecureSkipVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _insightsInsertKey?;
    /**
     * @stability stable
     */
    get insightsInsertKey(): string | undefined;
    /**
     * @stability stable
     */
    set insightsInsertKey(value: string | undefined);
    /**
     * @stability stable
     */
    resetInsightsInsertKey(): void;
    /**
     * @stability stable
     */
    get insightsInsertKeyInput(): string | undefined;
    private _insightsInsertUrl?;
    /**
     * @stability stable
     */
    get insightsInsertUrl(): string | undefined;
    /**
     * @stability stable
     */
    set insightsInsertUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetInsightsInsertUrl(): void;
    /**
     * @stability stable
     */
    get insightsInsertUrlInput(): string | undefined;
    private _insightsQueryUrl?;
    /**
     * @stability stable
     */
    get insightsQueryUrl(): string | undefined;
    /**
     * @stability stable
     */
    set insightsQueryUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetInsightsQueryUrl(): void;
    /**
     * @stability stable
     */
    get insightsQueryUrlInput(): string | undefined;
    private _nerdgraphApiUrl?;
    /**
     * @stability stable
     */
    get nerdgraphApiUrl(): string | undefined;
    /**
     * @stability stable
     */
    set nerdgraphApiUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetNerdgraphApiUrl(): void;
    /**
     * @stability stable
     */
    get nerdgraphApiUrlInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string | undefined;
    /**
     * @stability stable
     */
    set region(value: string | undefined);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _syntheticsApiUrl?;
    /**
     * @stability stable
     */
    get syntheticsApiUrl(): string | undefined;
    /**
     * @stability stable
     */
    set syntheticsApiUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetSyntheticsApiUrl(): void;
    /**
     * @stability stable
     */
    get syntheticsApiUrlInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
