import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NrqlAlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID for managing your NRQL alert conditions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#account_id NrqlAlertCondition#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * How long we wait for data that belongs in each aggregation window.
     *
     * Depending on your data, a longer delay may increase accuracy but delay notifications. Use aggregationDelay with the EVENT_FLOW and CADENCE aggregation methods.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#aggregation_delay NrqlAlertCondition#aggregation_delay}
     *
     * @stability stable
     */
    readonly aggregationDelay?: number;
    /**
     * The method that determines when we consider an aggregation window to be complete so that we can evaluate the signal for violations.
     *
     * Default is CADENCE.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#aggregation_method NrqlAlertCondition#aggregation_method}
     *
     * @stability stable
     */
    readonly aggregationMethod?: string;
    /**
     * How long we wait after each data point arrives to make sure we've processed the whole batch.
     *
     * Use aggregationTimer with the EVENT_TIMER aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#aggregation_timer NrqlAlertCondition#aggregation_timer}
     *
     * @stability stable
     */
    readonly aggregationTimer?: number;
    /**
     * The duration of the time window used to evaluate the NRQL query, in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#aggregation_window NrqlAlertCondition#aggregation_window}
     *
     * @stability stable
     */
    readonly aggregationWindow?: number;
    /**
     * The baseline direction of a baseline NRQL alert condition. Valid values are: 'LOWER_ONLY', 'UPPER_AND_LOWER', 'UPPER_ONLY' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#baseline_direction NrqlAlertCondition#baseline_direction}
     *
     * @stability stable
     */
    readonly baselineDirection?: string;
    /**
     * Whether to close all open violations when the signal expires.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#close_violations_on_expiration NrqlAlertCondition#close_violations_on_expiration}
     *
     * @stability stable
     */
    readonly closeViolationsOnExpiration?: boolean | cdktf.IResolvable;
    /**
     * The description of the NRQL alert condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#description NrqlAlertCondition#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Whether or not to enable the alert condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#enabled NrqlAlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Number of expected groups when using outlier detection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#expected_groups NrqlAlertCondition#expected_groups}
     *
     * @stability stable
     */
    readonly expectedGroups?: number;
    /**
     * The amount of time (in seconds) to wait before considering the signal expired.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#expiration_duration NrqlAlertCondition#expiration_duration}
     *
     * @stability stable
     */
    readonly expirationDuration?: number;
    /**
     * Which strategy to use when filling gaps in the signal.
     *
     * If static, the 'fill value' will be used for filling gaps in the signal. Valid values are: 'NONE', 'LAST_VALUE', or 'STATIC' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#fill_option NrqlAlertCondition#fill_option}
     *
     * @stability stable
     */
    readonly fillOption?: string;
    /**
     * If using the 'static' fill option, this value will be used for filling gaps in the signal.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#fill_value NrqlAlertCondition#fill_value}
     *
     * @stability stable
     */
    readonly fillValue?: number;
    /**
     * Whether to look for a convergence of groups when using outlier detection.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#ignore_overlap NrqlAlertCondition#ignore_overlap}
     *
     * @stability stable
     */
    readonly ignoreOverlap?: boolean | cdktf.IResolvable;
    /**
     * The title of the condition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#name NrqlAlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Whether to create a new violation to capture that the signal expired.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#open_violation_on_expiration NrqlAlertCondition#open_violation_on_expiration}
     *
     * @stability stable
     */
    readonly openViolationOnExpiration?: boolean | cdktf.IResolvable;
    /**
     * Whether overlapping groups should produce a violation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#open_violation_on_group_overlap NrqlAlertCondition#open_violation_on_group_overlap}
     *
     * @stability stable
     */
    readonly openViolationOnGroupOverlap?: boolean | cdktf.IResolvable;
    /**
     * The ID of the policy where this condition should be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#policy_id NrqlAlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#runbook_url NrqlAlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
    /**
     * The type of NRQL alert condition to create. Valid values are: 'static', 'baseline', 'outlier' (deprecated).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#type NrqlAlertCondition#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * Valid values are: 'single_value' or 'sum'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#value_function NrqlAlertCondition#value_function}
     *
     * @stability stable
     */
    readonly valueFunction?: string;
    /**
     * Sets a time limit, in hours, that will automatically force-close a long-lasting violation after the time limit you select.
     *
     * Possible values are 'ONE_HOUR', 'TWO_HOURS', 'FOUR_HOURS', 'EIGHT_HOURS', 'TWELVE_HOURS', 'TWENTY_FOUR_HOURS', 'THIRTY_DAYS' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#violation_time_limit NrqlAlertCondition#violation_time_limit}
     *
     * @stability stable
     */
    readonly violationTimeLimit?: string;
    /**
     * Sets a time limit, in seconds, that will automatically force-close a long-lasting violation after the time limit you select.
     *
     * Must be in the range of 300 to 2592000 (inclusive)
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#violation_time_limit_seconds NrqlAlertCondition#violation_time_limit_seconds}
     *
     * @stability stable
     */
    readonly violationTimeLimitSeconds?: number;
    /**
     * critical block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#critical NrqlAlertCondition#critical}
     *
     * @stability stable
     */
    readonly critical?: NrqlAlertConditionCritical;
    /**
     * nrql block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#nrql NrqlAlertCondition#nrql}
     *
     * @stability stable
     */
    readonly nrql: NrqlAlertConditionNrql;
    /**
     * term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#term NrqlAlertCondition#term}
     *
     * @stability stable
     */
    readonly term?: NrqlAlertConditionTerm[];
    /**
     * warning block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#warning NrqlAlertCondition#warning}
     *
     * @stability stable
     */
    readonly warning?: NrqlAlertConditionWarning;
}
/**
 * @stability stable
 */
export interface NrqlAlertConditionCritical {
    /**
     * In minutes, must be in the range of 1 to 120 (inclusive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#duration NrqlAlertCondition#duration}
     *
     * @stability stable
     */
    readonly duration?: number;
    /**
     * One of (above, below, equals). Defaults to 'equals'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#operator NrqlAlertCondition#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Must be 0 or greater. For baseline conditions must be in range [1, 1000].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold NrqlAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * The duration, in seconds, that the threshold must violate in order to create a violation.
     *
     * Value must be a multiple of the 'aggregation_window' (which has a default of 60 seconds). Value must be within 120-3600 seconds for baseline and outlier conditions, within 120-7200 seconds for static conditions with the sum value function, and within 60-7200 seconds for static conditions with the single_value value function.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_duration NrqlAlertCondition#threshold_duration}
     *
     * @stability stable
     */
    readonly thresholdDuration?: number;
    /**
     * The criteria for how many data points must be in violation for the specified threshold duration.
     *
     * Valid values are: 'ALL' or 'AT_LEAST_ONCE' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_occurrences NrqlAlertCondition#threshold_occurrences}
     *
     * @stability stable
     */
    readonly thresholdOccurrences?: string;
    /**
     * Valid values are: 'all' or 'any'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#time_function NrqlAlertCondition#time_function}
     *
     * @stability stable
     */
    readonly timeFunction?: string;
}
export declare function nrqlAlertConditionCriticalToTerraform(struct?: NrqlAlertConditionCriticalOutputReference | NrqlAlertConditionCritical): any;
/**
 * @stability stable
 */
export declare class NrqlAlertConditionCriticalOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): NrqlAlertConditionCritical | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: NrqlAlertConditionCritical | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    resetDuration(): void;
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _operator?;
    /**
     * @stability stable
     */
    get operator(): string;
    /**
     * @stability stable
     */
    set operator(value: string);
    /**
     * @stability stable
     */
    resetOperator(): void;
    /**
     * @stability stable
     */
    get operatorInput(): string | undefined;
    private _threshold?;
    /**
     * @stability stable
     */
    get threshold(): number;
    /**
     * @stability stable
     */
    set threshold(value: number);
    /**
     * @stability stable
     */
    get thresholdInput(): number | undefined;
    private _thresholdDuration?;
    /**
     * @stability stable
     */
    get thresholdDuration(): number;
    /**
     * @stability stable
     */
    set thresholdDuration(value: number);
    /**
     * @stability stable
     */
    resetThresholdDuration(): void;
    /**
     * @stability stable
     */
    get thresholdDurationInput(): number | undefined;
    private _thresholdOccurrences?;
    /**
     * @stability stable
     */
    get thresholdOccurrences(): string;
    /**
     * @stability stable
     */
    set thresholdOccurrences(value: string);
    /**
     * @stability stable
     */
    resetThresholdOccurrences(): void;
    /**
     * @stability stable
     */
    get thresholdOccurrencesInput(): string | undefined;
    private _timeFunction?;
    /**
     * @stability stable
     */
    get timeFunction(): string;
    /**
     * @stability stable
     */
    set timeFunction(value: string);
    /**
     * @stability stable
     */
    resetTimeFunction(): void;
    /**
     * @stability stable
     */
    get timeFunctionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface NrqlAlertConditionNrql {
    /**
     * NRQL queries are evaluated in one-minute time windows.
     *
     * The start time depends on the value you provide in the NRQL condition's `evaluation_offset`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#evaluation_offset NrqlAlertCondition#evaluation_offset}
     *
     * @stability stable
     */
    readonly evaluationOffset?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#query NrqlAlertCondition#query}.
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * NRQL queries are evaluated in one-minute time windows.
     *
     * The start time depends on the value you provide in the NRQL condition's `since_value`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#since_value NrqlAlertCondition#since_value}
     *
     * @stability stable
     */
    readonly sinceValue?: string;
}
export declare function nrqlAlertConditionNrqlToTerraform(struct?: NrqlAlertConditionNrqlOutputReference | NrqlAlertConditionNrql): any;
/**
 * @stability stable
 */
export declare class NrqlAlertConditionNrqlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): NrqlAlertConditionNrql | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: NrqlAlertConditionNrql | undefined);
    private _evaluationOffset?;
    /**
     * @stability stable
     */
    get evaluationOffset(): number;
    /**
     * @stability stable
     */
    set evaluationOffset(value: number);
    /**
     * @stability stable
     */
    resetEvaluationOffset(): void;
    /**
     * @stability stable
     */
    get evaluationOffsetInput(): number | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _sinceValue?;
    /**
     * @stability stable
     */
    get sinceValue(): string;
    /**
     * @stability stable
     */
    set sinceValue(value: string);
    /**
     * @stability stable
     */
    resetSinceValue(): void;
    /**
     * @stability stable
     */
    get sinceValueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface NrqlAlertConditionTerm {
    /**
     * In minutes, must be in the range of 1 to 120 (inclusive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#duration NrqlAlertCondition#duration}
     *
     * @stability stable
     */
    readonly duration?: number;
    /**
     * One of (above, below, equals). Defaults to 'equals'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#operator NrqlAlertCondition#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * One of (critical, warning). Defaults to 'critical'. At least one condition term must have priority set to 'critical'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#priority NrqlAlertCondition#priority}
     *
     * @stability stable
     */
    readonly priority?: string;
    /**
     * Must be 0 or greater. For baseline conditions must be in range [1, 1000].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold NrqlAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * The duration, in seconds, that the threshold must violate in order to create a violation.
     *
     * Value must be a multiple of the 'aggregation_window' (which has a default of 60 seconds). Value must be within 120-3600 seconds for baseline and outlier conditions, within 120-7200 seconds for static conditions with the sum value function, and within 60-7200 seconds for static conditions with the single_value value function.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_duration NrqlAlertCondition#threshold_duration}
     *
     * @stability stable
     */
    readonly thresholdDuration?: number;
    /**
     * The criteria for how many data points must be in violation for the specified threshold duration.
     *
     * Valid values are: 'ALL' or 'AT_LEAST_ONCE' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_occurrences NrqlAlertCondition#threshold_occurrences}
     *
     * @stability stable
     */
    readonly thresholdOccurrences?: string;
    /**
     * Valid values are: 'all' or 'any'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#time_function NrqlAlertCondition#time_function}
     *
     * @stability stable
     */
    readonly timeFunction?: string;
}
export declare function nrqlAlertConditionTermToTerraform(struct?: NrqlAlertConditionTerm): any;
/**
 * @stability stable
 */
export interface NrqlAlertConditionWarning {
    /**
     * In minutes, must be in the range of 1 to 120 (inclusive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#duration NrqlAlertCondition#duration}
     *
     * @stability stable
     */
    readonly duration?: number;
    /**
     * One of (above, below, equals). Defaults to 'equals'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#operator NrqlAlertCondition#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * Must be 0 or greater. For baseline conditions must be in range [1, 1000].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold NrqlAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * The duration, in seconds, that the threshold must violate in order to create a violation.
     *
     * Value must be a multiple of the 'aggregation_window' (which has a default of 60 seconds). Value must be within 120-3600 seconds for baseline and outlier conditions, within 120-7200 seconds for static conditions with the sum value function, and within 60-7200 seconds for static conditions with the single_value value function.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_duration NrqlAlertCondition#threshold_duration}
     *
     * @stability stable
     */
    readonly thresholdDuration?: number;
    /**
     * The criteria for how many data points must be in violation for the specified threshold duration.
     *
     * Valid values are: 'ALL' or 'AT_LEAST_ONCE' (case insensitive).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#threshold_occurrences NrqlAlertCondition#threshold_occurrences}
     *
     * @stability stable
     */
    readonly thresholdOccurrences?: string;
    /**
     * Valid values are: 'all' or 'any'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html#time_function NrqlAlertCondition#time_function}
     *
     * @stability stable
     */
    readonly timeFunction?: string;
}
export declare function nrqlAlertConditionWarningToTerraform(struct?: NrqlAlertConditionWarningOutputReference | NrqlAlertConditionWarning): any;
/**
 * @stability stable
 */
export declare class NrqlAlertConditionWarningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): NrqlAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: NrqlAlertConditionWarning | undefined);
    private _duration?;
    /**
     * @stability stable
     */
    get duration(): number;
    /**
     * @stability stable
     */
    set duration(value: number);
    /**
     * @stability stable
     */
    resetDuration(): void;
    /**
     * @stability stable
     */
    get durationInput(): number | undefined;
    private _operator?;
    /**
     * @stability stable
     */
    get operator(): string;
    /**
     * @stability stable
     */
    set operator(value: string);
    /**
     * @stability stable
     */
    resetOperator(): void;
    /**
     * @stability stable
     */
    get operatorInput(): string | undefined;
    private _threshold?;
    /**
     * @stability stable
     */
    get threshold(): number;
    /**
     * @stability stable
     */
    set threshold(value: number);
    /**
     * @stability stable
     */
    get thresholdInput(): number | undefined;
    private _thresholdDuration?;
    /**
     * @stability stable
     */
    get thresholdDuration(): number;
    /**
     * @stability stable
     */
    set thresholdDuration(value: number);
    /**
     * @stability stable
     */
    resetThresholdDuration(): void;
    /**
     * @stability stable
     */
    get thresholdDurationInput(): number | undefined;
    private _thresholdOccurrences?;
    /**
     * @stability stable
     */
    get thresholdOccurrences(): string;
    /**
     * @stability stable
     */
    set thresholdOccurrences(value: string);
    /**
     * @stability stable
     */
    resetThresholdOccurrences(): void;
    /**
     * @stability stable
     */
    get thresholdOccurrencesInput(): string | undefined;
    private _timeFunction?;
    /**
     * @stability stable
     */
    get timeFunction(): string;
    /**
     * @stability stable
     */
    set timeFunction(value: string);
    /**
     * @stability stable
     */
    resetTimeFunction(): void;
    /**
     * @stability stable
     */
    get timeFunctionInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html newrelic_nrql_alert_condition}.
 *
 * @stability stable
 */
export declare class NrqlAlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_alert_condition.html newrelic_nrql_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NrqlAlertConditionConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _aggregationDelay?;
    /**
     * @stability stable
     */
    get aggregationDelay(): number;
    /**
     * @stability stable
     */
    set aggregationDelay(value: number);
    /**
     * @stability stable
     */
    resetAggregationDelay(): void;
    /**
     * @stability stable
     */
    get aggregationDelayInput(): number | undefined;
    private _aggregationMethod?;
    /**
     * @stability stable
     */
    get aggregationMethod(): string;
    /**
     * @stability stable
     */
    set aggregationMethod(value: string);
    /**
     * @stability stable
     */
    resetAggregationMethod(): void;
    /**
     * @stability stable
     */
    get aggregationMethodInput(): string | undefined;
    private _aggregationTimer?;
    /**
     * @stability stable
     */
    get aggregationTimer(): number;
    /**
     * @stability stable
     */
    set aggregationTimer(value: number);
    /**
     * @stability stable
     */
    resetAggregationTimer(): void;
    /**
     * @stability stable
     */
    get aggregationTimerInput(): number | undefined;
    private _aggregationWindow?;
    /**
     * @stability stable
     */
    get aggregationWindow(): number;
    /**
     * @stability stable
     */
    set aggregationWindow(value: number);
    /**
     * @stability stable
     */
    resetAggregationWindow(): void;
    /**
     * @stability stable
     */
    get aggregationWindowInput(): number | undefined;
    private _baselineDirection?;
    /**
     * @stability stable
     */
    get baselineDirection(): string;
    /**
     * @stability stable
     */
    set baselineDirection(value: string);
    /**
     * @stability stable
     */
    resetBaselineDirection(): void;
    /**
     * @stability stable
     */
    get baselineDirectionInput(): string | undefined;
    private _closeViolationsOnExpiration?;
    /**
     * @stability stable
     */
    get closeViolationsOnExpiration(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set closeViolationsOnExpiration(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCloseViolationsOnExpiration(): void;
    /**
     * @stability stable
     */
    get closeViolationsOnExpirationInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _expectedGroups?;
    /**
     * @stability stable
     */
    get expectedGroups(): number;
    /**
     * @stability stable
     */
    set expectedGroups(value: number);
    /**
     * @stability stable
     */
    resetExpectedGroups(): void;
    /**
     * @stability stable
     */
    get expectedGroupsInput(): number | undefined;
    private _expirationDuration?;
    /**
     * @stability stable
     */
    get expirationDuration(): number;
    /**
     * @stability stable
     */
    set expirationDuration(value: number);
    /**
     * @stability stable
     */
    resetExpirationDuration(): void;
    /**
     * @stability stable
     */
    get expirationDurationInput(): number | undefined;
    private _fillOption?;
    /**
     * @stability stable
     */
    get fillOption(): string;
    /**
     * @stability stable
     */
    set fillOption(value: string);
    /**
     * @stability stable
     */
    resetFillOption(): void;
    /**
     * @stability stable
     */
    get fillOptionInput(): string | undefined;
    private _fillValue?;
    /**
     * @stability stable
     */
    get fillValue(): number;
    /**
     * @stability stable
     */
    set fillValue(value: number);
    /**
     * @stability stable
     */
    resetFillValue(): void;
    /**
     * @stability stable
     */
    get fillValueInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _ignoreOverlap?;
    /**
     * @stability stable
     */
    get ignoreOverlap(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ignoreOverlap(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIgnoreOverlap(): void;
    /**
     * @stability stable
     */
    get ignoreOverlapInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _openViolationOnExpiration?;
    /**
     * @stability stable
     */
    get openViolationOnExpiration(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set openViolationOnExpiration(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOpenViolationOnExpiration(): void;
    /**
     * @stability stable
     */
    get openViolationOnExpirationInput(): boolean | cdktf.IResolvable | undefined;
    private _openViolationOnGroupOverlap?;
    /**
     * @stability stable
     */
    get openViolationOnGroupOverlap(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set openViolationOnGroupOverlap(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOpenViolationOnGroupOverlap(): void;
    /**
     * @stability stable
     */
    get openViolationOnGroupOverlapInput(): boolean | cdktf.IResolvable | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _valueFunction?;
    /**
     * @stability stable
     */
    get valueFunction(): string;
    /**
     * @stability stable
     */
    set valueFunction(value: string);
    /**
     * @stability stable
     */
    resetValueFunction(): void;
    /**
     * @stability stable
     */
    get valueFunctionInput(): string | undefined;
    private _violationTimeLimit?;
    /**
     * @stability stable
     */
    get violationTimeLimit(): string;
    /**
     * @stability stable
     */
    set violationTimeLimit(value: string);
    /**
     * @stability stable
     */
    resetViolationTimeLimit(): void;
    /**
     * @stability stable
     */
    get violationTimeLimitInput(): string | undefined;
    private _violationTimeLimitSeconds?;
    /**
     * @stability stable
     */
    get violationTimeLimitSeconds(): number;
    /**
     * @stability stable
     */
    set violationTimeLimitSeconds(value: number);
    /**
     * @stability stable
     */
    resetViolationTimeLimitSeconds(): void;
    /**
     * @stability stable
     */
    get violationTimeLimitSecondsInput(): number | undefined;
    private _critical;
    /**
     * @stability stable
     */
    get critical(): NrqlAlertConditionCriticalOutputReference;
    /**
     * @stability stable
     */
    putCritical(value: NrqlAlertConditionCritical): void;
    /**
     * @stability stable
     */
    resetCritical(): void;
    /**
     * @stability stable
     */
    get criticalInput(): NrqlAlertConditionCritical | undefined;
    private _nrql;
    /**
     * @stability stable
     */
    get nrql(): NrqlAlertConditionNrqlOutputReference;
    /**
     * @stability stable
     */
    putNrql(value: NrqlAlertConditionNrql): void;
    /**
     * @stability stable
     */
    get nrqlInput(): NrqlAlertConditionNrql | undefined;
    private _term?;
    /**
     * @stability stable
     */
    get term(): NrqlAlertConditionTerm[];
    /**
     * @stability stable
     */
    set term(value: NrqlAlertConditionTerm[]);
    /**
     * @stability stable
     */
    resetTerm(): void;
    /**
     * @stability stable
     */
    get termInput(): NrqlAlertConditionTerm[] | undefined;
    private _warning;
    /**
     * @stability stable
     */
    get warning(): NrqlAlertConditionWarningOutputReference;
    /**
     * @stability stable
     */
    putWarning(value: NrqlAlertConditionWarning): void;
    /**
     * @stability stable
     */
    resetWarning(): void;
    /**
     * @stability stable
     */
    get warningInput(): NrqlAlertConditionWarning | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
