import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NrqlDropRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Account with the NRQL drop rule will be put.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html#account_id NrqlDropRule#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The drop rule action (drop_data, drop_attributes, or drop_attributes_from_metric_aggregates).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html#action NrqlDropRule#action}
     *
     * @stability stable
     */
    readonly action: string;
    /**
     * Provides additional information about the rule.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html#description NrqlDropRule#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Explains which data to apply the drop rule to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html#nrql NrqlDropRule#nrql}
     *
     * @stability stable
     */
    readonly nrql: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html newrelic_nrql_drop_rule}.
 *
 * @stability stable
 */
export declare class NrqlDropRule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/nrql_drop_rule.html newrelic_nrql_drop_rule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NrqlDropRuleConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _action?;
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    set action(value: string);
    /**
     * @stability stable
     */
    get actionInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _nrql?;
    /**
     * @stability stable
     */
    get nrql(): string;
    /**
     * @stability stable
     */
    set nrql(value: string);
    /**
     * @stability stable
     */
    get nrqlInput(): string | undefined;
    /**
     * @stability stable
     */
    get ruleId(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
