import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OneDashboardRawConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID where you want to create the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#account_id OneDashboardRaw#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The dashboard's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#description OneDashboardRaw#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#name OneDashboardRaw#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Determines who can see or edit the dashboard. Valid values are private, public_read_only, public_read_write. Defaults to public_read_only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#permissions OneDashboardRaw#permissions}
     *
     * @stability stable
     */
    readonly permissions?: string;
    /**
     * page block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#page OneDashboardRaw#page}
     *
     * @stability stable
     */
    readonly page: OneDashboardRawPage[];
}
/**
 * @stability stable
 */
export interface OneDashboardRawPageWidget {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#column OneDashboardRaw#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * The configuration of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#configuration OneDashboardRaw#configuration}
     *
     * @stability stable
     */
    readonly configuration: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#height OneDashboardRaw#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * (Optional) Related entity GUIDs. Currently only supports Dashboard entity GUIDs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#linked_entity_guids OneDashboardRaw#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#row OneDashboardRaw#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#title OneDashboardRaw#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * The visualization ID of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#visualization_id OneDashboardRaw#visualization_id}
     *
     * @stability stable
     */
    readonly visualizationId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#width OneDashboardRaw#width}.
     *
     * @stability stable
     */
    readonly width?: number;
}
export declare function oneDashboardRawPageWidgetToTerraform(struct?: OneDashboardRawPageWidget): any;
/**
 * @stability stable
 */
export interface OneDashboardRawPage {
    /**
     * The dashboard page's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#description OneDashboardRaw#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard page's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#name OneDashboardRaw#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * widget block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html#widget OneDashboardRaw#widget}
     *
     * @stability stable
     */
    readonly widget?: OneDashboardRawPageWidget[];
}
export declare function oneDashboardRawPageToTerraform(struct?: OneDashboardRawPage): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html newrelic_one_dashboard_raw}.
 *
 * @stability stable
 */
export declare class OneDashboardRaw extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard_raw.html newrelic_one_dashboard_raw} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: OneDashboardRawConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get permalink(): string;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string;
    /**
     * @stability stable
     */
    set permissions(value: string);
    /**
     * @stability stable
     */
    resetPermissions(): void;
    /**
     * @stability stable
     */
    get permissionsInput(): string | undefined;
    private _page?;
    /**
     * @stability stable
     */
    get page(): OneDashboardRawPage[];
    /**
     * @stability stable
     */
    set page(value: OneDashboardRawPage[]);
    /**
     * @stability stable
     */
    get pageInput(): OneDashboardRawPage[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
