import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PluginsAlertConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Whether or not this condition is enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#enabled PluginsAlertCondition#enabled}
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * The plugin component IDs to target.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#entities PluginsAlertCondition#entities}
     *
     * @stability stable
     */
    readonly entities: number[];
    /**
     * The plugin metric to evaluate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#metric PluginsAlertCondition#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The metric description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#metric_description PluginsAlertCondition#metric_description}
     *
     * @stability stable
     */
    readonly metricDescription: string;
    /**
     * The title of the condition. Must be between 1 and 64 characters, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#name PluginsAlertCondition#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The GUID of the plugin which produces the metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#plugin_guid PluginsAlertCondition#plugin_guid}
     *
     * @stability stable
     */
    readonly pluginGuid: string;
    /**
     * The ID of the installed plugin instance which produces the metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#plugin_id PluginsAlertCondition#plugin_id}
     *
     * @stability stable
     */
    readonly pluginId: string;
    /**
     * The ID of the policy where this condition should be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#policy_id PluginsAlertCondition#policy_id}
     *
     * @stability stable
     */
    readonly policyId: number;
    /**
     * Runbook URL to display in notifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#runbook_url PluginsAlertCondition#runbook_url}
     *
     * @stability stable
     */
    readonly runbookUrl?: string;
    /**
     * The value function to apply to the metric data.  One of `min`, `max`, `average`, `sample_size`, `total`, or `percent`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#value_function PluginsAlertCondition#value_function}
     *
     * @stability stable
     */
    readonly valueFunction: string;
    /**
     * term block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#term PluginsAlertCondition#term}
     *
     * @stability stable
     */
    readonly term: PluginsAlertConditionTerm[];
}
/**
 * @stability stable
 */
export interface PluginsAlertConditionTerm {
    /**
     * In minutes, must be in the range of 5 to 120, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#duration PluginsAlertCondition#duration}
     *
     * @stability stable
     */
    readonly duration: number;
    /**
     * One of `above`, `below`, or `equal`. Defaults to equal.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#operator PluginsAlertCondition#operator}
     *
     * @stability stable
     */
    readonly operator?: string;
    /**
     * One of `critical` or `warning`. Defaults to critical.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#priority PluginsAlertCondition#priority}
     *
     * @stability stable
     */
    readonly priority?: string;
    /**
     * Must be 0 or greater.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#threshold PluginsAlertCondition#threshold}
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * One of `all` or `any`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html#time_function PluginsAlertCondition#time_function}
     *
     * @stability stable
     */
    readonly timeFunction: string;
}
export declare function pluginsAlertConditionTermToTerraform(struct?: PluginsAlertConditionTerm): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html newrelic_plugins_alert_condition}.
 *
 * @stability stable
 */
export declare class PluginsAlertCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/plugins_alert_condition.html newrelic_plugins_alert_condition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PluginsAlertConditionConfig);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _entities?;
    /**
     * @stability stable
     */
    get entities(): number[];
    /**
     * @stability stable
     */
    set entities(value: number[]);
    /**
     * @stability stable
     */
    get entitiesInput(): number[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _metricDescription?;
    /**
     * @stability stable
     */
    get metricDescription(): string;
    /**
     * @stability stable
     */
    set metricDescription(value: string);
    /**
     * @stability stable
     */
    get metricDescriptionInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _pluginGuid?;
    /**
     * @stability stable
     */
    get pluginGuid(): string;
    /**
     * @stability stable
     */
    set pluginGuid(value: string);
    /**
     * @stability stable
     */
    get pluginGuidInput(): string | undefined;
    private _pluginId?;
    /**
     * @stability stable
     */
    get pluginId(): string;
    /**
     * @stability stable
     */
    set pluginId(value: string);
    /**
     * @stability stable
     */
    get pluginIdInput(): string | undefined;
    private _policyId?;
    /**
     * @stability stable
     */
    get policyId(): number;
    /**
     * @stability stable
     */
    set policyId(value: number);
    /**
     * @stability stable
     */
    get policyIdInput(): number | undefined;
    private _runbookUrl?;
    /**
     * @stability stable
     */
    get runbookUrl(): string;
    /**
     * @stability stable
     */
    set runbookUrl(value: string);
    /**
     * @stability stable
     */
    resetRunbookUrl(): void;
    /**
     * @stability stable
     */
    get runbookUrlInput(): string | undefined;
    private _valueFunction?;
    /**
     * @stability stable
     */
    get valueFunction(): string;
    /**
     * @stability stable
     */
    set valueFunction(value: string);
    /**
     * @stability stable
     */
    get valueFunctionInput(): string | undefined;
    private _term?;
    /**
     * @stability stable
     */
    get term(): PluginsAlertConditionTerm[];
    /**
     * @stability stable
     */
    set term(value: PluginsAlertConditionTerm[]);
    /**
     * @stability stable
     */
    get termInput(): PluginsAlertConditionTerm[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
